# Typed flags

[![builds.sr.ht status](https://builds.sr.ht/~tmk/typed-flags/unittest.yml.svg)](https://builds.sr.ht/~tmk/typed-flags/unittest.yml?)

[Tracker](https://todo.sr.ht/~tmk/typed-flags)

[Mailing list](https://lists.sr.ht/~tmk/typed-flags). Subscribe by sending an email to `~tmk/typed-flags+subscribe@lists.sr.ht`.
